[
http://jira.codehaus.org/browse/MERCURY-124?page=com.atlassian.jira.plugin.system.issuetabpanels:all-tabpanel
]
Oleg Gusakov closed MERCURY-124.
--------------------------------
Resolution: Fixed
Implemented on the transport level - upper levels don't have to know :)
Maven trunk build time came down 30% - 11 -> 7 min, this is already in the
acceptable range, and other measures can lower it
> pool HttpClient instances in the VirtualRepositoryReader and
> RemoteRepoWriterM2 instead of closing them
> -------------------------------------------------------------------------------------------------------
>
> Key: MERCURY-124
> URL: http://jira.codehaus.org/browse/MERCURY-124
> Project: Mercury
> Issue Type: Sub-task
> Reporter: Oleg Gusakov
>
--
This message is automatically generated by JIRA.
-
If you think it was sent incorrectly contact one of the administrators:
http://jira.codehaus.org/secure/Administrators.jspa
-
For more information on JIRA, see: http://www.atlassian.com/software/jira